
Sensitivity Functions
==========================================

Hyperparameter sensitivity linear approximation
-------------------------------------------------

.. autoclass:: vittles.sensitivity_lib.HyperparameterSensitivityLinearApproximation
  :members:

Hyperparameter sensitivity Taylor series approximation
---------------------------------------------------------

.. autoclass:: vittles.sensitivity_lib.ParametricSensitivityTaylorExpansion
  :members:

Optimum checking
---------------------------------------------------------

.. autoclass:: vittles.bivariate_sensitivity_lib.OptimumChecker
  :members:

.. autoclass:: vittles.bivariate_sensitivity_lib.CrossSensitivity
  :members:

Linear response covariances
----------------------------

.. autoclass:: vittles.lr_cov_lib.LinearResponseCovariances
  :members:
